:root{--accent-color:CornflowerBlue;--gray:#ccc}.s--inner.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku{padding:.5em;background-color:#fff;border:1px solid var(--gray)}[role=switch][aria-checked=true].svelte-1sy3hku .svelte-1sy3hku.svelte-1sy3hku:first-child,[role=switch][aria-checked=false].svelte-1sy3hku .svelte-1sy3hku.svelte-1sy3hku:last-child{display:none;color:#fff}.s--inner.svelte-1sy3hku button span.svelte-1sy3hku.svelte-1sy3hku{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;pointer-events:none;padding:.25em}.s--inner.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku:focus{outline:var(--accent-color) solid 1px}.s--slider.svelte-1sy3hku.svelte-1sy3hku.svelte-1sy3hku{display:flex;align-items:center}.s--slider.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku{width:3em;height:1.6em;position:relative;margin:0 0 0 .5em;background:var(--gray);border:none}.s--slider.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku:before{content:"";position:absolute;width:1.3em;height:1.3em;background:#fff;top:.13em;right:1.5em;transition:transform .3s}.s--slider.svelte-1sy3hku button[aria-checked=true].svelte-1sy3hku.svelte-1sy3hku{background-color:var(--accent-color)}.s--slider.svelte-1sy3hku button[aria-checked=true].svelte-1sy3hku.svelte-1sy3hku:before{transform:translate(1.3em);transition:transform .3s}.s--slider.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku:focus{box-shadow:0 0 0 1px var(--accent-color)}.s--multi.svelte-1sy3hku .group-container.svelte-1sy3hku.svelte-1sy3hku{border:none;padding:0;white-space:nowrap}.s--multi.svelte-1sy3hku label.svelte-1sy3hku.svelte-1sy3hku{display:inline-block;line-height:1.6;position:relative;z-index:2}.s--multi.svelte-1sy3hku input.svelte-1sy3hku.svelte-1sy3hku{opacity:0;position:absolute}.s--multi.svelte-1sy3hku label.svelte-1sy3hku.svelte-1sy3hku:first-of-type{padding-right:5em}.s--multi.svelte-1sy3hku label.svelte-1sy3hku.svelte-1sy3hku:last-child{margin-left:-5em;padding-left:5em}.s--multi.svelte-1sy3hku:focus-within label.svelte-1sy3hku.svelte-1sy3hku:first-of-type:after{box-shadow:0 0 8px var(--accent-color);border-radius:1.5em}.s--multi.svelte-1sy3hku label.svelte-1sy3hku.svelte-1sy3hku:first-of-type:before,.s--multi.svelte-1sy3hku label.svelte-1sy3hku.svelte-1sy3hku:first-of-type:after{content:"";height:1.25em;overflow:hidden;pointer-events:none;position:absolute;vertical-align:middle}.s--multi.svelte-1sy3hku label.svelte-1sy3hku.svelte-1sy3hku:first-of-type:before{border-radius:100%;z-index:2;position:absolute;width:1.2em;height:1.2em;background:#fff;top:.2em;right:1.2em;transition:transform .3s}.s--multi.svelte-1sy3hku label.svelte-1sy3hku.svelte-1sy3hku:first-of-type:after{background:var(--accent-color);border-radius:1em;margin:0 1em;transition:background .2s ease-in-out;width:3em;height:1.6em}.s--multi.svelte-1sy3hku input.svelte-1sy3hku:first-of-type:checked~label.svelte-1sy3hku:first-of-type:after{background:var(--gray)}.s--multi.svelte-1sy3hku input.svelte-1sy3hku:first-of-type:checked~label.svelte-1sy3hku:first-of-type:before{transform:translate(-1.4em)}.s--multi.svelte-1sy3hku input.svelte-1sy3hku:last-of-type:checked~label.svelte-1sy3hku:last-of-type{z-index:1}.s--multi.svelte-1sy3hku input.svelte-1sy3hku.svelte-1sy3hku:focus{box-shadow:0 0 8px var(--accent-color);border-radius:1.5em}[role=switch][aria-checked=true].svelte-1sy3hku .svelte-1sy3hku.svelte-1sy3hku:first-child,[role=switch][aria-checked=false].svelte-1sy3hku .svelte-1sy3hku.svelte-1sy3hku:last-child{border-radius:.25em;background:var(--accent-color);display:inline-block}.s--inner.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku:focus{box-shadow:0 0 8px var(--accent-color);border-radius:.1em}.s--slider.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku{border-radius:1.5em}.s--slider.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku:before{border-radius:100%}.s--slider.svelte-1sy3hku button.svelte-1sy3hku.svelte-1sy3hku:focus{box-shadow:0 0 8px var(--accent-color);border-radius:1.5em}.container.svelte-a4p85k{height:75vh}
